@@ -113,8 +113,11 @@ def post(url: str, data: Dict) -> Dict:
         try:
             if json.loads(rsp.text)['result'] == 'fail':
                 if json.loads(rsp.text)['message'] == "INVALID KEY":
-                    logger.error("Invalid Login Token.")
-                    raise Exception("Invalid Login Token.")
+                    logger.error("Invalid Login KEY.")
+                    raise Exception("Invalid Login KEY.")
+                if json.loads(rsp.text)['message'] == "invalid token":
+                    logger.error("Invalid Token.")
+                    raise Exception("Invalid Token.")
         except Exception as e :
             pass
         raise Exception(f"request.post() failed({rsp.text if rsp.text else rsp.status_code})", rsp)
